@@ -39,7 +39,7 @@ use Scalar::Util qw/blessed/;
 use String::Util qw/hascontent nocontent/;
 
 
-our $VERSION = '2.01';
+our $VERSION = '2.02';
 
 
 =head1 DESCRIPTION
@@ -1108,16 +1108,24 @@ L<ETL::Pipeline::Input>, L<ETL::Pipeline::Output>, L<ETL::Pipeline::Mapping>
 
 L<ETL::Pipeline::Input::Excel>, L<ETL::Pipeline::Input::DelimitedText>
 
+=head1 REPOSITORY
+
+L<https://github.com/rbwohlfarth/ETL-Pipeline>
+
 =head1 AUTHOR
 
 Robert Wohlfarth <robert.j.wohlfarth@vanderbilt.edu>
 
-=head1 LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2016 (c) Vanderbilt University Medical Center
+Copyright (c) 2016  Robert Wohlfarth
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This module is free software; you can redistribute it and/or modify it 
+under the same terms as Perl 5.10.0. For more details, see the full text 
+of the licenses in the directory LICENSES.
+
+This program is distributed in the hope that it will be useful, but 
+without any warranty; without even the implied
 
 =cut
 
